Learn R Programming

ig.vancouver.2014.topcolour (version 0.1.2.0)

topcolour-ig-vancouver-2014: Instagram 2014 Vancouver dataset top colour

Description

Top Colour of all Vancouver, BC Instagram 2014 thumbnails

Usage

data("topcolour.ig.vancouver.2014")

Arguments

Format

A data frame with 245736 observations on the following 2 variables: top colour and count. The top colour is the top colour from Vancouver, BC, Canada Instagram images taken in 2014.
colour
colour, in RGB Hex
count
count, the number of times that top colour occurs